==> ui-framework-elements-4.28.18-sources.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2078998421" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2078998421.a_1894881728" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2078998421.a196417563" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2078998421.a_1894679825" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_837291525" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_837291525.a_1358276382" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_837291525.a_1975970349" format="body2 widgetType" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_837291525.a_668752590" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));

==> ui-framework-elements-5.2.12-sources.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1067881171" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1067881171.a1590738942" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1067881171.a_864591397" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1067881171.a1590940845" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_523338286" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_523338286.a_1044323143" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_523338286.a76013098" format="body2 widgetType" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_523338286.a_893595909" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));
